@@ -1,7 +1,7 @@
 """DingTalk 协议适配器。
 
 本适配器适配了钉钉企业自建机器人协议。
-协议详情请参考: [钉钉开放平台](https://open.dingtalk.com/document/robots/robot-overview)。
+协议详情请参考：[钉钉开放平台](https://open.dingtalk.com/document/robots/robot-overview)。
 """
 import base64
 import hashlib
@@ -13,7 +13,7 @@ import aiohttp
 from aiohttp import web
 
 from alicebot.adapter import Adapter
-from alicebot.log import error_or_exception, logger
+from alicebot.log import logger
 
 from .config import Config
 from .event import DingTalkEvent
@@ -35,27 +35,27 @@ class DingTalkAdapter(Adapter[DingTalkEvent, Config]):
 
     session: aiohttp.ClientSession
 
-    async def startup(self):
+    async def startup(self) -> None:
         """创建 aiohttp Application。"""
         self.app = web.Application()
         self.app.add_routes([web.post(self.config.url, self.handler)])
 
         self.session = aiohttp.ClientSession()
 
-    async def run(self):
+    async def run(self) -> None:
         """运行 aiohttp 服务器。"""
         self.runner = web.AppRunner(self.app)
         await self.runner.setup()
         self.site = web.TCPSite(self.runner, self.config.host, self.config.port)
         await self.site.start()
 
-    async def shutdown(self):
+    async def shutdown(self) -> None:
         """清理 aiohttp AppRunner。"""
         await self.session.close()
         await self.site.stop()
         await self.runner.cleanup()
 
-    async def handler(self, request: web.Request):
+    async def handler(self, request: web.Request) -> web.Response:
         """处理 aiohttp 服务器的接收。
 
         Args:
@@ -63,7 +63,9 @@ class DingTalkAdapter(Adapter[DingTalkEvent, Config]):
         """
         if "timestamp" not in request.headers or "sign" not in request.headers:
             logger.error("Illegal http header, incomplete http header")
-        elif abs(int(request.headers["timestamp"]) - time.time() * 1000) > 3600000:
+        elif (
+            abs(int(request.headers["timestamp"]) - time.time() * 1000) > 60 * 60 * 1000
+        ):
             logger.error(
                 f'Illegal http header, timestamp: {request.headers["timestamp"]}'
             )
@@ -73,11 +75,7 @@ class DingTalkAdapter(Adapter[DingTalkEvent, Config]):
             try:
                 dingtalk_event = DingTalkEvent(adapter=self, **(await request.json()))
             except Exception as e:
-                error_or_exception(
-                    "Request parsing error:",
-                    e,
-                    self.bot.config.bot.log.verbose_exception,
-                )
+                self.bot.error_or_exception("Request parsing error:", e)
                 return web.Response()
             await self.handle_event(dingtalk_event)
         return web.Response()
@@ -143,13 +141,14 @@ class DingTalkAdapter(Adapter[DingTalkEvent, Config]):
             else:
                 raise TypeError(f"at must be Dict or DingTalkMessage, not {type(at)!r}")
 
+        data: Union[Dict[str, Any], DingTalkMessage]
         if conversation_type == "1":
             data = msg
         elif conversation_type == "2":
             if at is None:
-                data = {"msgtype": msg.type, **msg.as_dict()}
+                data = {"msgtype": msg.type, **msg.model_dump()}
             else:
-                data = {"msgtype": msg.type, **msg.as_dict(), **at.as_dict()}
+                data = {"msgtype": msg.type, **msg.model_dump(), **at.model_dump()}
         else:
             raise ValueError(
                 f'conversation_type must be "1" or "2" not {conversation_type}'
